%
%   invkin_sr  Solve for rho(t) given P(t) using Inverse Kinetics
%
%   Slightly modified version of Tom Michaud's Inverse_Kinetics_SR code to compute
%   reactivity versus time using the inverse kinetics method (using Simpson's 1/3  
%   Rule for the numerical integrations).
%
%   Modified by JRWhite, UMass-Lowell (Feb. 2014)

      function rhoinv = invkin_sr(Pn,t,lam,Co,samptime,Be,Gt,B)
% 
      Nt = length(t);
      Cinv = zeros(Nt,length(lam));  rhoinv = zeros(Nt,1);
      dpdt = zeros(Nt,1);
      Cinv(1,:) = Co;
      Cinvsum = zeros(Nt,1);
      Cinvsum(1) = Cinv(1,:)*lam';
%   
      for j = 2:Nt-1
        for i = 1:length(lam)                               % precursors
          Cinv(j,i) = exp(-lam(i)*samptime)*Cinv(j-1,i) + ...
              B(i)/Gt*samptime/6*(exp(-lam(i)*samptime)*Pn(j-1) + ...
              2*exp(-lam(i)*samptime/2)*(Pn(j-1)+Pn(j)) + Pn(j));
        end
        Cinvsum(j) = Cinv(j,:)*lam';
        dpdt(j) = (Pn(j+1)-Pn(j-1))/(2*samptime);       
        rhoinv(j) = Be + Gt/Pn(j)*(dpdt(j) - Cinvsum(j));   % reactivity
      end
      rhoinv(1) = rhoinv(2);     % set first point in data set to next calc value 
      rhoinv(Nt) = rhoinv(Nt-1); % set last point in data set to previous calc value
%
%   end of routine